@@ -43,6 +43,7 @@ import math
 import time
 import platform
 import collections
+import warnings
 from typing import Dict, List
 
 import tabulate
@@ -1287,6 +1288,9 @@ def test_cdist(ndim, input_dtype, out_dtype, metric, capability):
     A = A_extended[:, :ndim]
     B = B_extended[:, :ndim]
 
+    # Check if we need to round before casting to integer (to match SimSIMD's lround behavior)
+    is_integer_output = out_dtype in ("int32", "int64", "int16", "int8", "uint32", "uint64", "uint16", "uint8")
+
     if out_dtype is None:
         expected = spd.cdist(A, B, metric)
         result = simd.cdist(A, B, metric)
@@ -1297,7 +1301,9 @@ def test_cdist(ndim, input_dtype, out_dtype, metric, capability):
         assert spd.cdist(A, B, metric, out=expected_out) is not None
         assert simd.cdist(A, B, metric, out=result_out) is None
     else:
-        expected = spd.cdist(A, B, metric).astype(out_dtype)
+        #! SimSIMD rounds to the nearest integer before casting
+        scipy_result = spd.cdist(A, B, metric)
+        expected = np.round(scipy_result).astype(out_dtype) if is_integer_output else scipy_result.astype(out_dtype)
         result = simd.cdist(A, B, metric, out_dtype=out_dtype)
 
         #! Same functions can be used in-place, but SciPy doesn't support misaligned outputs
@@ -1307,7 +1313,7 @@ def test_cdist(ndim, input_dtype, out_dtype, metric, capability):
         assert spd.cdist(A, B, metric, out=expected_out) is not None
         assert simd.cdist(A, B, metric, out=result_out) is None
         #! Moreover, SciPy supports only double-precision outputs, so we need to downcast afterwards.
-        expected_out = expected_out.astype(out_dtype)
+        expected_out = np.round(expected_out).astype(out_dtype) if is_integer_output else expected_out.astype(out_dtype)
 
     # Assert they're close.
     np.testing.assert_allclose(result, expected, atol=SIMSIMD_ATOL, rtol=SIMSIMD_RTOL)
@@ -1328,12 +1334,17 @@ def test_cdist_itself(ndim, input_dtype, out_dtype, metric):
 
     np.random.seed()
 
+    # Check if we need to round before casting to integer (to match SimSIMD's lround behavior)
+    is_integer_output = out_dtype in ("int32", "int64", "int16", "int8", "uint32", "uint64", "uint16", "uint8")
+
     A = np.random.randn(10, ndim + 1).astype(input_dtype)
     if out_dtype is None:
         expected = spd.cdist(A, A, metric)
         result = simd.cdist(A, A, metric=metric)
     else:
-        expected = spd.cdist(A, A, metric).astype(out_dtype)
+        #! SimSIMD rounds to the nearest integer before casting
+        scipy_result = spd.cdist(A, A, metric)
+        expected = np.round(scipy_result).astype(out_dtype) if is_integer_output else scipy_result.astype(out_dtype)
         result = simd.cdist(A, A, metric=metric, out_dtype=out_dtype)
 
     # Assert they're close.
@@ -1488,9 +1499,9 @@ def test_gil_free_threading():
 
     # Warn if multi-threaded execution is slower than the baseline
     if baseline_duration < multi_duration:
-        pytest.warns(
-            UserWarning,
+        warnings.warn(
             f"{num_threads}-threaded execution took longer than 2-threaded baseline: {multi_duration:.2f}s vs {baseline_duration:.2f}s",
+            UserWarning,
         )
 
 
